@@ -21,9 +21,20 @@
   
    Authors: Alexander Larsson <alexl@redhat.com>
 */
+
+#include "config.h"
+
+#ifdef __FreeBSD__
+#include <sys/param.h>
+#include <sys/mount.h>
+#else
 #include <sys/vfs.h>
+#endif /* __FreeBSD__ */
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef HAVE_STATVFS
+#include <sys/statvfs.h>
+#endif
 #include <time.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -36,6 +47,10 @@
 
 #include "nautilus-cd-burner.h"
 
+#ifndef HAVE_MKDTEMP
+#include "mkdtemp.h"
+#endif
+
 static void
 write_all (int fd, char *buf, int len)
 {
@@ -470,9 +485,17 @@ make_iso (const char *filename, const char *label)
 	char *dirname;
 	int exit_status, res;
 	unsigned long iso_size;
+#ifdef HAVE_STATVFS
+	struct statvfs statfs_buf;
+#else
 	struct statfs statfs_buf;
+#endif
 	GtkWidget *dialog;
 
+	if (label) {
+		g_return_val_if_fail (strlen (label) < 32, RESULT_ERROR);
+	}
+
 	dirname = g_strdup_printf ("iso-%s.XXXXXX", g_get_user_name ());
 	tempdir = g_build_filename (g_get_tmp_dir (), dirname, NULL);
 	g_free (dirname);
@@ -547,11 +570,16 @@ make_iso (const char *filename, const char *label)
 	g_free (stdout_data);
 
 	dirname = g_path_get_dirname (filename);
+#ifdef HAVE_STATVFS
+	res = statvfs (dirname, &statfs_buf);
+#else
 	res = statfs (dirname, &statfs_buf);
-	g_free (dirname);
+#endif
 	if (res == -1) {
 		g_warning ("Cannot get free space at %s\n", dirname);
+		g_free (dirname);
 	} else if (iso_size / statfs_buf.f_bsize >= statfs_buf.f_bavail / 2048) {
+		g_free (dirname);
 		dialog = gtk_message_dialog_new (cd_progress_get_window (),
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
@@ -565,7 +593,7 @@ make_iso (const char *filename, const char *label)
 		mkisofs_output.result = RESULT_ERROR;
 		goto cleanup;
 	}
-	
+
 	i = 0;
 	argv[i++] = "mkisofs";
 	argv[i++] = "-r";
@@ -573,8 +601,10 @@ make_iso (const char *filename, const char *label)
 	argv[i++] = "-graft-points";
 	argv[i++] = "-path-list";
 	argv[i++] = filelist;
-	argv[i++] = "-A";
-	argv[i++] = label;
+	if (label) {
+		argv[i++] = "-V";
+		argv[i++] = label;
+	}
 	argv[i++] = "-o";
 	argv[i++] = filename;
 	argv[i++] = NULL;
@@ -641,3 +671,42 @@ make_iso (const char *filename, const char *label)
 
 	return mkisofs_output.result;
 }
+
+gint 
+build_list_of_music_arguments (char *uri, int *argc, const char **argv, int max_num_args)
+{
+	GnomeVFSFileInfo *info;
+	GnomeVFSDirectoryHandle *handle;
+	GnomeVFSResult result;
+	char *backing;
+	gint count;
+
+	count = 0;
+	
+	result = gnome_vfs_directory_open (&handle, uri, GNOME_VFS_FILE_INFO_FOLLOW_LINKS | GNOME_VFS_FILE_INFO_GET_MIME_TYPE);
+	if (result != GNOME_VFS_OK) {
+		return 0;
+	}
+	
+	info = gnome_vfs_file_info_new ();
+
+	while (TRUE) {
+		result = gnome_vfs_directory_read_next (handle, info);
+		if (result != GNOME_VFS_OK)
+			break;
+
+		if (is_audio (info->mime_type)) {
+			backing = get_backing_file (info->name);
+			argv[(*argc)++] = backing;
+			count++;
+		}
+		
+		if (count == max_num_args) {
+			break;		
+		}
+	}
+
+	gnome_vfs_directory_close (handle);
+	gnome_vfs_file_info_unref (info);
+	return count;
+}
