@@ -22,3 +22,5 @@
    Authors: Alexander Larsson <alexl@redhat.com>
 */
 int make_iso (const char *filename, const char *label);
+gint build_list_of_music_arguments (char *uri, int *argc, const char **argv, int max_num_args);
+extern gboolean is_audio (char *mime_type);
