@@ -35,6 +35,10 @@
 #include <glib/glist.h>
 #include <libgnomevfs/gnome-vfs.h>
 
+#ifndef HAVE_MKDTEMP
+#include "mkdtemp.h"
+#endif
+
 #include "mapping-daemon.h"
 #include "mapping-protocol.h"
 
@@ -121,11 +125,13 @@ static VirtualRoot *
 virtual_root_new (const char *method)
 {
 	VirtualRoot *root;
-	char *tempdir;
+	char *tempdir, *filename;
 	char *dir;
 
-	tempdir = g_strdup_printf ("/tmp/virtual-%s.XXXXXX", g_get_user_name ());
-	
+	filename = g_strdup_printf ("virtual-%s.XXXXXX", g_get_user_name ());
+	tempdir = g_build_filename (g_get_tmp_dir(), filename, NULL);
+	g_free (filename);
+
 	root = g_new (VirtualRoot, 1);
 	
 	dir = mkdtemp (tempdir);
@@ -866,11 +872,10 @@ main (int argc, char *argv[])
                 exit(1);
         }
 	
-	sin.sun_family = AF_UNIX;	
-	strcpy (sin.sun_path, "/tmp/mapping-");
-	strcat (sin.sun_path, g_get_user_name ());
+	sin.sun_family = AF_UNIX;
+	g_snprintf (sin.sun_path, sizeof(sin.sun_path), "%s/mapping-%s", g_get_tmp_dir (), g_get_user_name ());
 	unlink (sin.sun_path);
-	if (bind (master_socket, &sin, sizeof(sin)) == -1) {
+	if (bind (master_socket, (const struct sockaddr *)&sin, sizeof(sin)) == -1) {
                 perror ("Failed to bind master socket");
                 exit(1);
         }
