@@ -938,19 +938,18 @@ vfs_module_init (const char *method_name, const char *args)
 {
         struct sockaddr_un sin;
 
-	sin.sun_family = AF_UNIX;	
-	strcpy (sin.sun_path, "/tmp/mapping-");
-	strcat (sin.sun_path, g_get_user_name ());
+	sin.sun_family = AF_UNIX;
+	g_snprintf (sin.sun_path, sizeof(sin.sun_path), "%s/mapping-%s", g_get_tmp_dir (), g_get_user_name ());
 
         if ((daemon_fd = socket (AF_UNIX, SOCK_STREAM, 0)) == -1) {
                 perror("mapping method init - socket");
                 return NULL;
         }
 	
-        if (connect (daemon_fd, &sin, sizeof(sin)) == -1) {
+        if (connect (daemon_fd, (const struct sockaddr *) &sin, sizeof(sin)) == -1) {
 		if (errno == ECONNREFUSED || errno == ENOENT) {
 			if (launch_daemon ()) {
-				if (connect (daemon_fd, &sin, sizeof(sin)) == -1) {
+				if (connect (daemon_fd,  (const struct sockaddr *) &sin, sizeof(sin)) == -1) {
 					perror("mapping method init - connect2");
 					return NULL;
 				}
@@ -959,8 +958,8 @@ vfs_module_init (const char *method_name, const char *args)
 			}
 		} else {
 			perror("mapping method init - connect");
+			return NULL;
 		}
-                return NULL;
         }
 
 	mapping_lock = g_mutex_new();
